@@ -257,10 +257,16 @@ class GPUArray(object):
         return self._axpbz(-1, other, result)
 
     def __iadd__(self, other):
-        return self._axpbyz(1, other, 1, self)
+        if isinstance(other, GPUArray):
+            return self._axpbyz(1, other, 1, self)
+        else:
+            return self._axpbz(1, other, self)
 
     def __isub__(self, other):
-        return self._axpbyz(1, other, -1, self)
+        if isinstance(other, GPUArray):
+            return self._axpbyz(1, other, -1, self)
+        else:
+            return self._axpbz(1, -other, self)
 
     def __neg__(self):
         result = self._new_like_me()
@@ -529,24 +535,84 @@ class GPUArray(object):
         else:
             return self
 
-    # rich comparisons (or rather, lack thereof) ------------------------------
+    # rich comparisons 
     def __eq__(self, other):
-        raise NotImplementedError
+        """Return self == other"""
+
+        result = self._new_like_me()
+
+        func = elementwise.get_eq_kernel(self.dtype, other.dtype, result.dtype)
+        func.set_block_shape(*self._block)
+        func.prepared_async_call(self._grid, None,
+                self.gpudata, other.gpudata, result.gpudata,
+                self.mem_size)
+
+        return result        
 
     def __ne__(self, other):
-        raise NotImplementedError
+        """Return self != other"""
+
+        result = self._new_like_me()
+
+        func = elementwise.get_ne_kernel(self.dtype, other.dtype, result.dtype)
+        func.set_block_shape(*self._block)
+        func.prepared_async_call(self._grid, None,
+                self.gpudata, other.gpudata, result.gpudata,
+                self.mem_size)
+
+        return result     
 
     def __le__(self, other):
-        raise NotImplementedError
+        """Return self <= other"""
+
+        result = self._new_like_me()
+
+        func = elementwise.get_le_kernel(self.dtype, other.dtype, result.dtype)
+        func.set_block_shape(*self._block)
+        func.prepared_async_call(self._grid, None,
+                self.gpudata, other.gpudata, result.gpudata,
+                self.mem_size)
+
+        return result
 
     def __ge__(self, other):
-        raise NotImplementedError
+        """Return self >= other"""
 
+        result = self._new_like_me()
+
+        func = elementwise.get_ge_kernel(self.dtype, other.dtype, result.dtype)
+        func.set_block_shape(*self._block)
+        func.prepared_async_call(self._grid, None,
+                self.gpudata, other.gpudata, result.gpudata,
+                self.mem_size)
+
+        return result
+    
     def __lt__(self, other):
-        raise NotImplementedError
+        """Return self < other"""
+
+        result = self._new_like_me()
+
+        func = elementwise.get_lt_kernel(self.dtype, other.dtype, result.dtype)
+        func.set_block_shape(*self._block)
+        func.prepared_async_call(self._grid, None,
+                self.gpudata, other.gpudata, result.gpudata,
+                self.mem_size)
+
+        return result
 
     def __gt__(self, other):
-        raise NotImplementedError
+        """Return self > other"""
+
+        result = self._new_like_me()
+
+        func = elementwise.get_gt_kernel(self.dtype, other.dtype, result.dtype)
+        func.set_block_shape(*self._block)
+        func.prepared_async_call(self._grid, None,
+                self.gpudata, other.gpudata, result.gpudata,
+                self.mem_size)
+
+        return result
 
 
 
@@ -881,18 +947,26 @@ def if_positive(criterion, then_, else_, out=None, stream=None):
 
 
 
-def maximum(a, b, out=None, stream=None):
-    # silly, but functional
-    return if_positive(a.mul_add(1, b, -1, stream=stream), a, b, 
-            stream=stream, out=out)
+def _make_binary_minmax_func(which):
+    def f(a, b, out=None, stream=None):
+        if out is None:
+            out = empty_like(a)
+
+        func = elementwise.get_binary_minmax_kernel(which,
+                a.dtype, b.dtype, out.dtype)
+
+        func.set_block_shape(*a._block)
+        func.prepared_async_call(a._grid, stream,
+                a.gpudata, b.gpudata, out.gpudata, a.size)
+
+        return out
+    return f
 
 
 
 
-def minimum(a, b, out=None, stream=None):
-    # silly, but functional
-    return if_positive(a.mul_add(1, b, -1, stream=stream), b, a, 
-            stream=stream, out=out)
+minimum = _make_binary_minmax_func("min")
+maximum = _make_binary_minmax_func("max")
 
 
 
