@@ -24,14 +24,17 @@ namespace
       pointer_type allocate(size_type s)
       {
         cuda::scoped_context_activation ca(get_context());
-
         return cuda::mem_alloc(s);
       }
 
       void free(pointer_type p)
       {
-        cuda::scoped_context_activation ca(get_context());
-        cuda::mem_free(p);
+        try
+        {
+          cuda::scoped_context_activation ca(get_context());
+          cuda::mem_free(p);
+        }
+        CUDAPP_CATCH_CLEANUP_ON_DEAD_CONTEXT(pooled_device_allocation);
       }
 
       void try_release_blocks()
@@ -45,13 +48,20 @@ namespace
 
   class host_allocator
   {
+    private:
+      unsigned m_flags;
+
     public:
       typedef void *pointer_type;
       typedef unsigned int size_type;
 
+      host_allocator(unsigned flags=0)
+        : m_flags(flags)
+      { }
+
       pointer_type allocate(size_type s)
       {
-        return cuda::mem_alloc_host(s);
+        return cuda::mem_alloc_host(s, m_flags);
       }
 
       void free(pointer_type p)
@@ -222,12 +232,21 @@ void pycuda_expose_tools()
     expose_memory_pool(wrapper);
   }
 
+  {
+    typedef host_allocator cl;
+    py::class_<cl> wrapper("PageLockedAllocator",
+        py::init<py::optional<unsigned> >());
+  }
+
   {
     typedef pycuda::memory_pool<host_allocator> cl;
 
     py::class_<
       cl, boost::noncopyable, 
-      boost::shared_ptr<cl> > wrapper("PageLockedMemoryPool");
+      boost::shared_ptr<cl> > wrapper(
+          "PageLockedMemoryPool",
+          py::init<py::optional<host_allocator const &> >()
+          );
     wrapper
       .def("allocate", host_pool_allocate,
           (py::arg("shape"), py::arg("dtype"), py::arg("order")="C"));
